summaryrefslogtreecommitdiff
path: root/src/map/pet.c
diff options
context:
space:
mode:
authorAsheraf <acheraf1998@gmail.com>2018-07-17 19:33:32 +0100
committerAsheraf <acheraf1998@gmail.com>2018-07-24 14:21:01 +0100
commit0ad1e08ee15ac0112cad6d94e67584a5ce571c53 (patch)
tree26c5499cd4684f736bf5e8d986ce12d35fe474a2 /src/map/pet.c
parent504ad2ca7d6ef4923093f74ac2afd5fc1bd39fd1 (diff)
downloadhercules-0ad1e08ee15ac0112cad6d94e67584a5ce571c53.tar.gz
hercules-0ad1e08ee15ac0112cad6d94e67584a5ce571c53.tar.bz2
hercules-0ad1e08ee15ac0112cad6d94e67584a5ce571c53.tar.xz
hercules-0ad1e08ee15ac0112cad6d94e67584a5ce571c53.zip
Correct wrong attribute used for pet evolution egg hiding
Diffstat (limited to 'src/map/pet.c')
-rw-r--r--src/map/pet.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/map/pet.c b/src/map/pet.c
index e544905c0..5d0e5b9e3 100644
--- a/src/map/pet.c
+++ b/src/map/pet.c
@@ -345,7 +345,7 @@ static int pet_return_egg(struct map_session_data *sd, struct pet_data *pd)
pd->pet.pet_id == MakeDWord(sd->status.inventory[i].card[1], sd->status.inventory[i].card[2]));
if (i != MAX_INVENTORY) {
- sd->status.inventory[i].identify = 1;
+ sd->status.inventory[i].attribute &= ~ATTR_BROKEN;
sd->status.inventory[i].bound = IBT_NONE;
}
@@ -496,8 +496,8 @@ static int pet_recv_petdata(int account_id, struct s_pet *p, int flag)
if (!pet->birth_process(sd,p)) {
- // Pet Evolution, Hide the egg by setting identify to 0 [Dastgir/Hercules]
- sd->status.inventory[i].identify = 0;
+ // Pet Evolution, Hide the egg by setting broken attribute (0x2) [Asheraf]
+ sd->status.inventory[i].attribute |= ATTR_BROKEN;
// bind the egg to the character to avoid moving it via forged packets [Asheraf]
sd->status.inventory[i].bound = IBT_CHARACTER;
}